==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/serder/SearchSortGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class SearchSortGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.SearchSort> {

	public SearchSortGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.SearchSort deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.SearchSort ret = new net.bluemind.backend.mail.api.SearchSort();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.SearchSort ret, JSONObject json) {

		JSONValue criteriaJSON = json.get("criteria");
		ret.criteria =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).deserialize(criteriaJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.SearchSort o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.SearchSort o, JSONObject ret) {

		ret.put("criteria",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).serialize( o.criteria ));
	}
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/backend/mail/api/gwt/serder/SearchSortGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class SearchSortGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.SearchSort> {

	public SearchSortGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.SearchSort deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.SearchSort ret = new net.bluemind.backend.mail.api.SearchSort();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.SearchSort ret, JSONObject json) {
		JSONValue criteriaJSON = json.get("criteria");
		ret.criteria =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).deserialize(criteriaJSON);
	}

	public void deserializeTo(net.bluemind.backend.mail.api.SearchSort ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("criteria")) {
			JSONValue criteriaJSON = json.get("criteria");
			ret.criteria =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).deserialize(criteriaJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.SearchSort o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.SearchSort o, JSONObject ret) {

		ret.put("criteria",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).serialize( o.criteria ));
	}

	public void serializeTo(net.bluemind.backend.mail.api.SearchSort o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("criteria")) {
			ret.put("criteria",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.backend.mail.api.gwt.serder.SearchSortSortCriteriaGwtSerDer()).serialize( o.criteria ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
